@@ -31,7 +31,6 @@
 #include "keep-alive.h"
 #include <gjs/gjs-module.h>
 #include <gjs/compat.h>
-#include <gjs/runtime.h>
 
 typedef struct {
     GClosure base;
@@ -254,6 +253,7 @@ gjs_closure_invoke(GClosure *closure,
 {
     Closure *c;
     JSContext *context;
+    JSObject *global;
 
     c = (Closure*) closure;
 
@@ -265,8 +265,10 @@ gjs_closure_invoke(GClosure *closure,
         return;
     }
 
-    context = gjs_runtime_get_context(c->runtime);
+    context = c->context;
     JS_BeginRequest(context);
+    global = JS_GetGlobalObject(context);
+    JSAutoCompartment ac(context, global);
 
     if (JS_IsExceptionPending(context)) {
         gjs_debug_closure("Exception was pending before invoking callback??? "
@@ -307,14 +309,14 @@ gjs_closure_is_valid(GClosure *closure)
     return c->context != NULL;
 }
 
-JSRuntime*
-gjs_closure_get_runtime(GClosure *closure)
+JSContext*
+gjs_closure_get_context(GClosure *closure)
 {
     Closure *c;
 
     c = (Closure*) closure;
 
-    return c->runtime;
+    return c->context;
 }
 
 JSObject*
@@ -338,7 +340,7 @@ gjs_closure_trace(GClosure *closure,
     if (c->obj == NULL)
         return;
 
-    JS_CALL_OBJECT_TRACER(tracer, c->obj, "signal connection");
+    JS_CallObjectTracer(tracer, &c->obj, "signal connection");
 }
 
 GClosure*
