@@ -32,7 +32,6 @@
 #include "gtype.h"
 #include <gjs/gjs-module.h>
 #include <gjs/compat.h>
-#include <gjs/runtime.h>
 
 #include <util/log.h>
 
@@ -414,7 +413,7 @@ struct JSClass gjs_param_class = {
     "GObject_ParamSpec",
     JSCLASS_HAS_PRIVATE,
     JS_PropertyStub,
-    JS_PropertyStub,
+    JS_DeletePropertyStub,
     param_get_prop,
     JS_StrictPropertyStub,
     JS_EnumerateStub,
