@@ -33,16 +33,18 @@
 G_BEGIN_DECLS
 
 JSBool      gjs_define_repo                     (JSContext      *context,
-                                                 JSObject       *module_obj,
+                                                 JSObject      **module_out,
                                                  const char     *name);
 const char* gjs_info_type_name                  (GIInfoType      type);
 JSObject*   gjs_lookup_private_namespace        (JSContext      *context);
 JSObject*   gjs_lookup_namespace_object         (JSContext      *context,
                                                  GIBaseInfo     *info);
 JSObject*   gjs_lookup_namespace_object_by_name (JSContext      *context,
-                                                 const char     *name);
+                                                 jsid            name);
 JSObject*   gjs_lookup_function_object          (JSContext      *context,
                                                  GIFunctionInfo *info);
+JSObject *  gjs_lookup_generic_prototype        (JSContext      *context,
+                                                 GIBaseInfo     *info);
 JSBool      gjs_define_info                     (JSContext      *context,
                                                  JSObject       *in_object,
                                                  GIBaseInfo     *info);
