@@ -27,12 +27,17 @@
 #include <locale.h>
 
 #include <gjs/gjs.h>
+#include <gjs/coverage.h>
 
 static char **include_path = NULL;
+static char **coverage_paths = NULL;
+static char *coverage_output_path = NULL;
 static char *command = NULL;
 
 static GOptionEntry entries[] = {
     { "command", 'c', 0, G_OPTION_ARG_STRING, &command, "Program passed in as a string", "COMMAND" },
+    { "coverage-path", 'C', 0, G_OPTION_ARG_STRING_ARRAY, &coverage_paths, "Add the filename FILE to the list of files to generate coverage info for", "FILE" },
+    { "coverage-output", 0, 0, G_OPTION_ARG_STRING, &coverage_output_path, "Write coverage output to a directory DIR. This option is mandatory when using --coverage-path", "DIR", },
     { "include-path", 'I', 0, G_OPTION_ARG_STRING_ARRAY, &include_path, "Add the directory DIR to the list of directories to search for js files.", "DIR" },
     { NULL }
 };
@@ -57,6 +62,7 @@ main(int argc, char **argv)
     GOptionContext *context;
     GError *error = NULL;
     GjsContext *js_context;
+    GjsCoverage *coverage = NULL;
     char *script;
     const char *filename;
     const char *program_name;
@@ -111,6 +117,14 @@ main(int argc, char **argv)
                                             "program-name", program_name,
                                             NULL);
 
+    if (coverage_paths) {
+        if (!coverage_output_path)
+            g_error("--coverage-output is required when taking coverage statistics");
+
+        coverage = gjs_coverage_new((const gchar **) coverage_paths,
+                                    js_context);
+    }
+
     /* prepare command line arguments */
     if (!gjs_context_define_string_array(js_context, "ARGV",
                                          argc - 1, (const char**)argv + 1,
@@ -131,6 +145,12 @@ main(int argc, char **argv)
     }
 
  out:
+
+    /* Probably doesn't make sense to write statistics on failure */
+    if (coverage && code == 0)
+        gjs_coverage_write_statistics(coverage,
+                                      coverage_output_path);
+ 
     g_object_unref(js_context);
     g_free(script);
     exit(code);
