@@ -247,6 +247,9 @@ JSObject*   gjs_construct_object_dynamic     (JSContext       *context,
                                               JSObject        *proto,
                                               unsigned         argc,
                                               jsval           *argv);
+JSObject*   gjs_build_string_array           (JSContext       *context,
+                                              gssize           array_length,
+                                              char           **array_values);
 JSObject*   gjs_define_string_array          (JSContext       *context,
                                               JSObject        *obj,
                                               const char      *array_name,
@@ -351,6 +354,12 @@ JSBool      gjs_parse_args                   (JSContext  *context,
                                               jsval     *argv,
                                               ...);
 
+JSBool      gjs_parse_call_args              (JSContext    *context,
+                                              const char   *function_name,
+                                              const char   *format,
+                                              JS::CallArgs &args,
+                                              ...);
+
 GjsRootedArray*   gjs_rooted_array_new        (void);
 void              gjs_rooted_array_append     (JSContext        *context,
                                                GjsRootedArray *array,
